Index: channels/chan_sip.c
===================================================================
--- channels/chan_sip.c	(revision 72986)
+++ channels/chan_sip.c	(working copy)
@@ -1244,7 +1244,7 @@
 /*! \brief A per-thread temporary pvt structure */
 AST_THREADSTORAGE_CUSTOM(ts_temp_pvt, temp_pvt_init, temp_pvt_cleanup);
 
-/*! \breif Authentication list for realm authentication 
+/*! \brief Authentication list for realm authentication 
  * \todo Move the sip_auth list to AST_LIST */
 static struct sip_auth *authl = NULL;
 
Index: apps/app_voicemail.c
===================================================================
--- apps/app_voicemail.c	(revision 72986)
+++ apps/app_voicemail.c	(working copy)
@@ -35,7 +35,7 @@
  *
  *
  *
- * \note  This file is now almost impossible to work with, due to all #ifdefs.
+ * \note  This file is now almost impossible to work with, due to all \#ifdefs.
  *        Feels like the database code before realtime. Someone - please come up
  *        with a plan to clean this up.
  */
Index: funcs/func_devstate.c
===================================================================
--- funcs/func_devstate.c	(revision 72986)
+++ funcs/func_devstate.c	(working copy)
@@ -24,7 +24,7 @@
  *
  * \ingroup functions
  *
- * \note Props go out to Ahrimanes in #asterisk for requesting this at 4:30 AM
+ * \note Props go out to Ahrimanes in \#asterisk for requesting this at 4:30 AM
  *       when I couldn't sleep.  :)
  */
 
Index: include/asterisk/channel.h
===================================================================
--- include/asterisk/channel.h	(revision 72986)
+++ include/asterisk/channel.h	(working copy)
@@ -107,12 +107,12 @@
 	so a transcoding module is needed.
 
 References:
-        - ast_channel_early_bridge()
-        - ast_channel_bridge()
-	- app_meetme.c
-	- \ref AstRTPbridge
-        - ast_rtp_bridge() 
-	- \ref Def_Channel
+        \li \see ast_channel_early_bridge()
+        \li \see ast_channel_bridge()
+	\li \see app_meetme.c
+	\li \ref AstRTPbridge
+        \li \see ast_rtp_bridge() 
+	\li \ref Def_Channel
 */
 
 /*! \page AstFileDesc File descriptors 
Index: include/asterisk/app.h
===================================================================
--- include/asterisk/app.h	(revision 72986)
+++ include/asterisk/app.h	(working copy)
@@ -165,10 +165,13 @@
 
 /*! 
  * \brief Stream a file with fast forward, pause, reverse, restart. 
- * \param offsetms Before calling this function, set this to be the number 
- *        of ms to start from the beginning of the file.  When the function
- *        returns, it will be the number of ms from the beginning where the
- *        playback stopped.  Pass NULL if you don't care.
+ * \param chan 
+ * \param file filename
+ * \param fwd, rev, stop, pause, restart, skipms, offsetms 
+ * Before calling this function, set this to be the number 
+ * of ms to start from the beginning of the file.  When the function
+ * returns, it will be the number of ms from the beginning where the
+ * playback stopped.  Pass NULL if you don't care.
  */
 int ast_control_streamfile(struct ast_channel *chan, const char *file, const char *fwd, const char *rev, const char *stop, const char *pause, const char *restart, int skipms, long *offsetms);
 
Index: main/ast_expr2f.c
===================================================================
--- main/ast_expr2f.c	(revision 72986)
+++ main/ast_expr2f.c	(working copy)
@@ -1676,7 +1676,8 @@
 #define YY_RULE_SETUP \
 	YY_USER_ACTION
 
-/** The main scanner function which does all the work.
+/*!
+ * \brief The main scanner function which does all the work.
  */
 YY_DECL
 {
@@ -2438,10 +2439,11 @@
 }
 #endif	/* ifndef YY_NO_INPUT */
 
-/** Immediately switch to a different input stream.
- * @param input_file A readable stream.
- * @param yyscanner The scanner object.
- * @note This function does not reset the start condition to @c INITIAL .
+/*!
+ * \brief Immediately switch to a different input stream.
+ * \param input_file A readable stream.
+ * \param yyscanner The scanner object.
+ * \note This function does not reset the start condition to \c INITIAL .
  */
     void ast_yyrestart  (FILE * input_file , yyscan_t yyscanner)
 {
@@ -2457,9 +2459,10 @@
 	ast_yy_load_buffer_state(yyscanner );
 }
 
-/** Switch to a different input buffer.
- * @param new_buffer The new input buffer.
- * @param yyscanner The scanner object.
+/*!
+ * \brief Switch to a different input buffer.
+ * \param new_buffer The new input buffer.
+ * \param yyscanner The scanner object.
  */
     void ast_yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer , yyscan_t yyscanner)
 {
@@ -2502,11 +2505,12 @@
 	yyg->yy_hold_char = *yyg->yy_c_buf_p;
 }
 
-/** Allocate and initialize an input buffer state.
- * @param file A readable stream.
- * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
- * @param yyscanner The scanner object.
- * @return the allocated buffer state.
+/*!
+ * \brief Allocate and initialize an input buffer state.
+ * \param file A readable stream.
+ * \param size The character buffer size in bytes. When in doubt, use \c YY_BUF_SIZE.
+ * \param yyscanner The scanner object.
+ * \return the allocated buffer state.
  */
     YY_BUFFER_STATE ast_yy_create_buffer  (FILE * file, int  size , yyscan_t yyscanner)
 {
@@ -2532,9 +2536,10 @@
 	return b;
 }
 
-/** Destroy the buffer.
- * @param b a buffer created with ast_yy_create_buffer()
- * @param yyscanner The scanner object.
+/*!
+ * \brief Destroy the buffer.
+ * \param b a buffer created with ast_yy_create_buffer()
+ * \param yyscanner The scanner object.
  */
     void ast_yy_delete_buffer (YY_BUFFER_STATE  b , yyscan_t yyscanner)
 {
@@ -2585,9 +2590,10 @@
 	errno = oerrno;
 }
 
-/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
- * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
- * @param yyscanner The scanner object.
+/*!
+ * \brief Discard all buffered characters. On the next scan, YY_INPUT will be called.
+ * \param b the buffer state to be flushed, usually \c YY_CURRENT_BUFFER.
+ * \param yyscanner The scanner object.
  */
     void ast_yy_flush_buffer (YY_BUFFER_STATE  b , yyscan_t yyscanner)
 {
@@ -2613,11 +2619,11 @@
 		ast_yy_load_buffer_state(yyscanner );
 }
 
-/** Pushes the new state onto the stack. The new state becomes
- *  the current state. This function will allocate the stack
- *  if necessary.
- *  @param new_buffer The new state.
- *  @param yyscanner The scanner object.
+/*!
+ * \brief Pushes the new state onto the stack. The new state becomes
+ *  the current state. This function will allocate the stack if necessary.
+ *  \param new_buffer The new state.
+ *  \param yyscanner The scanner object.
  */
 void ast_yypush_buffer_state (YY_BUFFER_STATE new_buffer , yyscan_t yyscanner)
 {
@@ -2646,9 +2652,10 @@
 	yyg->yy_did_buffer_switch_on_eof = 1;
 }
 
-/** Removes and deletes the top of the stack, if present.
+/*!
+ * \brief Removes and deletes the top of the stack, if present.
  *  The next element becomes the new top.
- *  @param yyscanner The scanner object.
+ *  \param yyscanner The scanner object.
  */
 void ast_yypop_buffer_state (yyscan_t yyscanner)
 {
@@ -2667,8 +2674,8 @@
 	}
 }
 
-/* Allocates the stack if it does not exist.
- *  Guarantees space for at least one push.
+/*!
+ * \brief Allocates the stack if it does not exist Guarantees space for at least one push.
  */
 static void ast_yyensure_buffer_stack (yyscan_t yyscanner)
 {
@@ -2710,11 +2717,12 @@
 	}
 }
 
-/** Setup the input buffer state to scan directly from a user-specified character buffer.
- * @param base the character buffer
- * @param size the size in bytes of the character buffer
- * @param yyscanner The scanner object.
- * @return the newly allocated buffer state object. 
+/*!
+ * \brief Setup the input buffer state to scan directly from a user-specified character buffer.
+ * \param base the character buffer
+ * \param size the size in bytes of the character buffer
+ * \param yyscanner The scanner object.
+ * \return the newly allocated buffer state object. 
  */
 YY_BUFFER_STATE ast_yy_scan_buffer  (char * base, yy_size_t  size , yyscan_t yyscanner)
 {
@@ -2745,12 +2753,13 @@
 	return b;
 }
 
-/** Setup the input buffer state to scan a string. The next call to ast_yylex() will
- * scan from a @e copy of @a str.
- * @param str a NUL-terminated string to scan
- * @param yyscanner The scanner object.
- * @return the newly allocated buffer state object.
- * @note If you want to scan bytes that may contain NUL values, then use
+/*!
+ * \brief Setup the input buffer state to scan a string. The next call to ast_yylex() will
+ * scan from a \e copy of \a str.
+ * \param yy_str a NUL-terminated string to scan
+ * \param yyscanner The scanner object.
+ * \return the newly allocated buffer state object.
+ * \note If you want to scan bytes that may contain NUL values, then use
  *       ast_yy_scan_bytes() instead.
  */
 YY_BUFFER_STATE ast_yy_scan_string (yyconst char * yy_str , yyscan_t yyscanner)
@@ -2759,12 +2768,13 @@
 	return ast_yy_scan_bytes(yy_str,strlen(yy_str) ,yyscanner);
 }
 
-/** Setup the input buffer state to scan the given bytes. The next call to ast_yylex() will
+/*!
+ * \brief Setup the input buffer state to scan the given bytes. The next call to ast_yylex() will
  * scan from a @e copy of @a bytes.
- * @param bytes the byte buffer to scan
- * @param len the number of bytes in the buffer pointed to by @a bytes.
- * @param yyscanner The scanner object.
- * @return the newly allocated buffer state object.
+ * \param bytes the byte buffer to scan
+ * \param len the number of bytes in the buffer pointed to by @a bytes.
+ * \param yyscanner The scanner object.
+ * \return the newly allocated buffer state object.
  */
 YY_BUFFER_STATE ast_yy_scan_bytes  (yyconst char * bytes, int  len , yyscan_t yyscanner)
 {
@@ -2825,8 +2835,9 @@
 
 /* Accessor  methods (get/set functions) to struct members. */
 
-/** Get the user-defined data for this scanner.
- * @param yyscanner The scanner object.
+/*!
+ * \brief Get the user-defined data for this scanner.
+ * \param yyscanner The scanner object.
  */
 YY_EXTRA_TYPE ast_yyget_extra  (yyscan_t yyscanner)
 {
@@ -2834,8 +2845,9 @@
     return yyextra;
 }
 
-/** Get the current line number.
- * @param yyscanner The scanner object.
+/*!
+ * \brief Get the current line number.
+ * \param yyscanner The scanner object.
  */
 int ast_yyget_lineno  (yyscan_t yyscanner)
 {
@@ -2847,8 +2859,9 @@
     return yylineno;
 }
 
-/** Get the current column number.
- * @param yyscanner The scanner object.
+/*! 
+ * \brief Get the current column number.
+ * \param yyscanner The scanner object.
  */
 int ast_yyget_column  (yyscan_t yyscanner)
 {
@@ -2860,8 +2873,9 @@
     return yycolumn;
 }
 
-/** Get the input stream.
- * @param yyscanner The scanner object.
+/*!
+ * \brief Get the input stream.
+ * \param yyscanner The scanner object.
  */
 FILE *ast_yyget_in  (yyscan_t yyscanner)
 {
@@ -2869,8 +2883,9 @@
     return yyin;
 }
 
-/** Get the output stream.
- * @param yyscanner The scanner object.
+/*!
+ * \brief Get the output stream.
+ * \param yyscanner The scanner object.
  */
 FILE *ast_yyget_out  (yyscan_t yyscanner)
 {
@@ -2878,8 +2893,9 @@
     return yyout;
 }
 
-/** Get the length of the current token.
- * @param yyscanner The scanner object.
+/*!
+ * \brief Get the length of the current token.
+ * \param yyscanner The scanner object.
  */
 int ast_yyget_leng  (yyscan_t yyscanner)
 {
@@ -2888,7 +2904,7 @@
 }
 
 /** Get the current token.
- * @param yyscanner The scanner object.
+ * \param yyscanner The scanner object.
  */
 
 char *ast_yyget_text  (yyscan_t yyscanner)
@@ -2897,9 +2913,10 @@
     return yytext;
 }
 
-/** Set the user-defined data. This data is never touched by the scanner.
- * @param user_defined The data to be associated with this scanner.
- * @param yyscanner The scanner object.
+/*!
+ * \brief Set the user-defined data. This data is never touched by the scanner.
+ * \param user_defined The data to be associated with this scanner.
+ * \param yyscanner The scanner object.
  */
 void ast_yyset_extra (YY_EXTRA_TYPE  user_defined , yyscan_t yyscanner)
 {
@@ -2907,9 +2924,10 @@
     yyextra = user_defined ;
 }
 
-/** Set the current line number.
- * @param line_number
- * @param yyscanner The scanner object.
+/*! 
+ * \brief Set the current line number.
+ * \param line_number
+ * \param yyscanner The scanner object.
  */
 void ast_yyset_lineno (int  line_number , yyscan_t yyscanner)
 {
@@ -2922,9 +2940,10 @@
     yylineno = line_number;
 }
 
-/** Set the current column.
- * @param line_number
- * @param yyscanner The scanner object.
+/*!
+ * \brief Set the current column.
+ * \param column_no
+ * \param yyscanner The scanner object.
  */
 void ast_yyset_column (int  column_no , yyscan_t yyscanner)
 {
@@ -2937,11 +2956,11 @@
     yycolumn = column_no;
 }
 
-/** Set the input stream. This does not discard the current
- * input buffer.
- * @param in_str A readable stream.
- * @param yyscanner The scanner object.
- * @see ast_yy_switch_to_buffer
+/*!
+ * \brief Set the input stream. This does not discard the current input buffer.
+ * \param in_str A readable stream.
+ * \param yyscanner The scanner object.
+ * \see ast_yy_switch_to_buffer
  */
 void ast_yyset_in (FILE *  in_str , yyscan_t yyscanner)
 {
